@@ -260,9 +260,7 @@ except:
     file = open("pywhatkit_dbs.txt","w",encoding='utf-8')
     print("""Hello from the creator of pywhatkit, Ankit Raj Mahapatra.\nKindly do report bugs if any
 What's new:
-1. Removed selenium dependent functions
-2. Added pywhatkit.text_to_handwriting() which will convert text to handwritten characters.
-3. Added pywhatkit.image_to_ascii_art() which will convert image to ascii art.""")
+1. Fixed text_to_handwriting() function""")
     file.write("--------------------\n")
     file.close()
     file = None
